@@ -16,8 +16,7 @@ teardown() {
 }
 
 main() {
-    export KUBEVIRT_PROVIDER='k8s-1.19'
-    export KUBEVIRT_NUM_NODES=3 # 1 master, 2 workers
+    export KUBEVIRT_NUM_NODES=5 # 1 master, 4 workers
     source automation/check-patch.setup.sh
     cd ${TMP_PROJECT_PATH}
 
@@ -33,13 +32,8 @@ main() {
     make cluster-sync
 
     export E2E_TEST_SUITE_ARGS="--junit-output=$ARTIFACTS/junit.functest.xml"
-    if [ "$NMSTATE_PARALLEL_ROLLOUT" == "true" ]; then
-       E2E_TEST_SUITE_ARGS="${E2E_TEST_SUITE_ARGS} -ginkgo.skip='user-guide|nns|sequential'"
-    else
-       E2E_TEST_SUITE_ARGS="${E2E_TEST_SUITE_ARGS} -ginkgo.skip='parallel'"
-    fi
 
-    make E2E_TEST_TIMEOUT=1h E2E_TEST_ARGS="-noColor" test-e2e-handler
+    make E2E_TEST_TIMEOUT=80m E2E_TEST_ARGS="-noColor" test-e2e-handler
 }
 
 [[ "${BASH_SOURCE[0]}" == "$0" ]] && main "$@"
